<?php

namespace Drupal\varnish_file_purge\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure file purge settings for this site.
 */
class VarnishFilePurgeConfiguration extends ConfigFormBase {

  /**
   * The configuration key.
   *
   * @var string
   */
  public const CONFIG_KEY = 'varnish_file_purge.configuration';

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'varnish_file_purge_configuration_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return [self::CONFIG_KEY];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config(self::CONFIG_KEY);

    $form['domains'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Domains'),
      '#description' => $this->t('The different domains of the site, separated by commas. Set it up for sites which front URL is different than the backoffice URL.'),
      '#default_value' => $config->get('domains'),
    ];

    $form['debug'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Debug'),
      '#description' => $this->t('By checking this, a log will be created for each time a file is purged. Use it only for debugging purposes.'),
      '#default_value' => $config->get('debug') ?? FALSE,
    ];

    $form['varnish_configuration'] = [
      '#type' => 'details',
      '#title' => t('Varnish configuration'),
      '#weight' => 3,
      '#open' => TRUE,
    ];

    $form['varnish_configuration']['host'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Host name'),
      '#default_value' => $config->get('host') ?? '',
      '#description' => $this->t('Varnish host name.'),
      '#required' => TRUE,
    ];

    $form['varnish_configuration']['port'] = [
      '#type' => 'number',
      '#title' => $this->t('Port'),
      '#default_value' => $config->get('port') ?? '',
      '#description' => $this->t('Varnish port.'),
      '#min' => 0,
      '#max' => 65535,
    ];

    $form['varnish_configuration']['scheme'] = [
      '#title' => $this->t('SCHEME'),
      '#type' => 'select',
      '#default_value' => $config->get('scheme') ?? 'http',
      '#options' => ['http://' => 'HTTP', 'https://' => 'HTTPS'],
    ];

    $form['varnish_configuration']['request_method'] = [
      '#title' => $this->t('Request Method'),
      '#type' => 'select',
      '#default_value' => $config->get('request_method') ?? 'purge',
      '#options' => ['ban' => 'BAN', 'purge' => 'PURGE'],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config(self::CONFIG_KEY)
      ->set('debug', $form_state->getValue('debug'))
      ->set('domains', $form_state->getValue('domains'))
      ->set('host', $form_state->getValue('host'))
      ->set('port', $form_state->getValue('port'))
      ->set('scheme', $form_state->getValue('scheme'))
      ->set('request_method', $form_state->getValue('request_method'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
